@@ -66,7 +66,9 @@
 import_presens = function(file, o2_unit = 'percent_a.s.', date = '%d/%m/%y', sal = 35, all_cols = FALSE, split_channels = FALSE)
 {
 	raw = readChar(file, nchars = file.info(file)$size, useBytes = TRUE)
-	raw = gsub(pattern = '\xb0|\xa9|\xfc\xbe\x8e\x93\xa0\xbc', replacement = ' ', raw) # replace non ASCII characters
+	#raw = gsub(pattern = '\xb0|\xa9|\xfc\xbe\x8e\x93\xa0\xbc', replacement = ' ', raw) # replace non ASCII characters
+	Encoding(raw) = 'UTF-8'
+	raw = iconv(raw, 'UTF-8', 'UTF-8', sub = ' ')
 	raw = strsplit(raw, split = '\r*\n')[[1]]
 	raw = raw[sapply(raw, nchar) > 0] # remove blank rows
   
